@@ -251,7 +251,7 @@ C         PRINT DISCORDANCY MEASURES
 C
   140 CONTINUE
       IF(KPRINT.LE.0)GOTO 160
-      WRITE(KOUT,6000)
+Calberto      WRITE(KOUT,6000)
       DCRIT1=DC1(1)
       DCRIT2=DC2(1)
       IF(NSITES.LE.14)DCRIT1=DC1(NSITES)
@@ -263,11 +263,11 @@ C
       IF(D(I).GE.DCRIT1)LOOK1=STAR
       IF(D(I).GE.DCRIT2)LOOK2=STAR
       IF(D(I).LT.DCRIT1)KSTART=KSTART+1
-      WRITE(KOUT,6010)I,LEN(I),NAMES(I),(XMOM(K,I),K=2,4),
-     *  D(I),LOOK1,LOOK2
+Calberto      WRITE(KOUT,6010)I,LEN(I),NAMES(I),(XMOM(K,I),K=2,4),
+Calberto     *  D(I),LOOK1,LOOK2
   150 CONTINUE
-      WRITE(KOUT,6020)(RMOM(K),K=2,4)
-      IF(KSTART.LT.NSITES)WRITE(KOUT,6030)(WORK(K,1),K=KSTART,NSITES)
+Calberto      WRITE(KOUT,6020)(RMOM(K),K=2,4)
+Calberto      IF(KSTART.LT.NSITES)WRITE(KOUT,6030)(WORK(K,1),K=KSTART,NSITES)
   160 CONTINUE
 C
       IF(NSIM.LE.0)RETURN
@@ -281,7 +281,8 @@ C
       IF(IFAIL.EQ.0)GOTO 180
       CALL PELGLO(RMOM,RPARA)
       RPARA(4)=-ONE
-  180 IF(KPRINT.GT.0)WRITE(KOUT,6040)(RPARA(K),K=1,4)
+Calberto  180 IF(KPRINT.GT.0)WRITE(KOUT,6040)(RPARA(K),K=1,4)
+  180 CONTINUE
 C
 C         START THE NSIM REPETITIONS
 C
@@ -380,7 +381,7 @@ C
 C
 C         CALCULATE AND PRINT HETEROGENEITY MEASURES (H STATISTICS)
 C
-      IF(KPRINT.GT.0)WRITE(KOUT,6050)NSIM
+Calberto      IF(KPRINT.GT.0)WRITE(KOUT,6050)NSIM
       DO 230 J=1,3
       VBAR(J)=VBAR(J)/NSIM
       VSD(J)=DSQRT((VSD(J)-NSIM*VBAR(J)**2)/(NSIM-ONE))
@@ -390,9 +391,9 @@ C
       LOOK2=BLANK
       IF(H(J).GE.HCRIT1)LOOK1=STAR
       IF(H(J).GE.HCRIT2)LOOK2=STAR
-      IF(J.EQ.1)WRITE(KOUT,6060)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
-      IF(J.EQ.2)WRITE(KOUT,6070)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
-      IF(J.EQ.3)WRITE(KOUT,6080)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
+Calberto      IF(J.EQ.1)WRITE(KOUT,6060)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
+Calberto      IF(J.EQ.2)WRITE(KOUT,6070)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
+Calberto      IF(J.EQ.3)WRITE(KOUT,6080)VOBS(J),VBAR(J),VSD(J),H(J),LOOK1,LOOK2
   230 CONTINUE
   235 CONTINUE
 C
@@ -418,11 +419,12 @@ C
 C         PRINT Z STATISTICS
 C
       IF(KPRINT.LE.0)GOTO 260
-      WRITE(KOUT,6090)NSIM
+Calberto      WRITE(KOUT,6090)NSIM
       DO 250 IDIST=1,5
       LOOK1=BLANK
       IF(DABS(Z(IDIST)).LT.ZCRIT)LOOK1=STAR
-  250 WRITE(KOUT,6100)DISTRI(IDIST),T4FIT(IDIST),Z(IDIST),LOOK1
+Calberto  250 WRITE(KOUT,6100)DISTRI(IDIST),T4FIT(IDIST),Z(IDIST),LOOK1
+  250 CONTINUE
   260 CONTINUE
 C
 C         FIT DISTRIBUTIONS
@@ -438,18 +440,18 @@ C
 C         FOR SUCCESSFUL CANDIDATES AND WAKEBY, PRINT PARAMETERS ...
 C
       IF(KPRINT.LE.0)GOTO 320
-      IF(NSIM.EQ.1)WRITE(KOUT,6110)
-      IF(NSIM.GT.1)WRITE(KOUT,6120)
+Calberto      IF(NSIM.EQ.1)WRITE(KOUT,6110)
+Calberto      IF(NSIM.GT.1)WRITE(KOUT,6120)
       DO 280 IDIST=1,5
-      IF(DABS(Z(IDIST)).LE.ZCRIT)
-     *  WRITE(KOUT,6130)DISTRI(IDIST),(PARA(IPARA,IDIST),IPARA=1,3)
+Calberto      IF(DABS(Z(IDIST)).LE.ZCRIT)
+Calberto     *  WRITE(KOUT,6130)DISTRI(IDIST),(PARA(IPARA,IDIST),IPARA=1,3)
   280 CONTINUE
-      WRITE(KOUT,6130)DISTRI(6),(PARA(IPARA,6),IPARA=1,5)
+Calberto      WRITE(KOUT,6130)DISTRI(6),(PARA(IPARA,6),IPARA=1,5)
 C
 C         ... AND ESTIMATE AND PRINT QUANTILES
 C
       IF(NPROB.EQ.0)GOTO 320
-      WRITE(KOUT,6140)PROB
+Calberto      WRITE(KOUT,6140)PROB
       DO 300 IDIST=1,5
       IF(DABS(Z(IDIST)).GT.ZCRIT)GOTO 300
       DO 290 IQ=1,NPROB
@@ -459,23 +461,23 @@ C
       IF(IDIST.EQ.4)Q(IQ)=QUAPE3(PROB(IQ),PARA(1,4))
       IF(IDIST.EQ.5)Q(IQ)=QUAGPA(PROB(IQ),PARA(1,5))
   290 CONTINUE
-      WRITE(KOUT,6150)DISTRI(IDIST),(Q(IQ),IQ=1,NPROB)
+Calberto      WRITE(KOUT,6150)DISTRI(IDIST),(Q(IQ),IQ=1,NPROB)
   300 CONTINUE
       DO 310 IQ=1,NPROB
   310 Q(IQ)=QUAWAK(PROB(IQ),PARA(1,6))
-      WRITE(KOUT,6150)DISTRI(6),(Q(IQ),IQ=1,NPROB)
+Calberto      WRITE(KOUT,6150)DISTRI(6),(Q(IQ),IQ=1,NPROB)
   320 CONTINUE
 C
       RETURN
 C
- 1000 WRITE(KOUT,7000)'MAXNS'
-      RETURN
- 1010 WRITE(KOUT,7000)'MAXQ'
-      RETURN
- 1020 WRITE(KOUT,7000)'MAXREC'
-      RETURN
- 1030 WRITE(KOUT,7010)
-      GOTO 140
+Calberto 1000 WRITE(KOUT,7000)'MAXNS'
+ 1000 RETURN
+Calberto 1010 WRITE(KOUT,7000)'MAXQ'
+ 1010 RETURN
+Calberto 1020 WRITE(KOUT,7000)'MAXREC'
+ 1020 RETURN
+Calberto 1030 WRITE(KOUT,7010)
+ 1030 GOTO 140
 C
  6000 FORMAT(/' SITE    N      NAME       L-CV   L-SKEW  L-KURT   D(I)')
  6010 FORMAT(2I5,2X,A12,3F8.4,F7.2,2X,2A1)
